==> haskell-pipes-safe-2.3.5-70.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-safe
version:              2.3.5
visibility:           public
id:                   pipes-safe-2.3.5-EaNnEnDIKVFAc7jRb9iGoI
key:                  pipes-safe-2.3.5-EaNnEnDIKVFAc7jRb9iGoI
license:              BSD-3-Clause
copyright:            2013, 2014 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Safety for the pipes ecosystem
description:
    This package adds resource management and exception handling to the @pipes@
    ecosystem.

    Notable features include:

    * /Resource Safety/: Guarantee finalization using @finally@, @bracket@ and
    more

    * /Exception Safety/: Even against asynchronous exceptions!

    * /Laziness/: Only acquire resources when you need them

    * /Promptness/: Finalize resources early when you are done with them

    * /Native Exception Handling/: Catch and resume from exceptions inside pipes

    * /No Buy-in/: Mix resource-safe pipes with unmanaged pipes using @hoist@

category:             Control, Pipes, Error Handling
abi:                  d18fde1345dd01b893e1891a75d74846
exposed:              True
exposed-modules:      Pipes.Safe Pipes.Safe.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-safe-2.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-safe-2.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-safe-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-safe
hs-libraries:         HSpipes-safe-2.3.5-EaNnEnDIKVFAc7jRb9iGoI
depends:
    base-4.18.2.1 containers-0.6.7 exceptions-0.10.7
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    pipes-4.3.16-1cweUqtcPZw1FLNBrZvQ72
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:   /usr/share/doc/haskell-pipes-safe/html/pipes-safe.haddock
haddock-html:         /usr/share/doc/haskell-pipes-safe/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-safe-2.3.5-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-safe
version:              2.3.5
visibility:           public
id:                   pipes-safe-2.3.5-Ainp3R9oYLr5M6BNlGkAnB
key:                  pipes-safe-2.3.5-Ainp3R9oYLr5M6BNlGkAnB
license:              BSD-3-Clause
copyright:            2013, 2014 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Safety for the pipes ecosystem
description:
    This package adds resource management and exception handling to the @pipes@
    ecosystem.

    Notable features include:

    * /Resource Safety/: Guarantee finalization using @finally@, @bracket@ and
    more

    * /Exception Safety/: Even against asynchronous exceptions!

    * /Laziness/: Only acquire resources when you need them

    * /Promptness/: Finalize resources early when you are done with them

    * /Native Exception Handling/: Catch and resume from exceptions inside pipes

    * /No Buy-in/: Mix resource-safe pipes with unmanaged pipes using @hoist@

category:             Control, Pipes, Error Handling
abi:                  0e85ff80ccd2a677a47d61e24d5d0dc7
exposed:              True
exposed-modules:      Pipes.Safe Pipes.Safe.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-safe-2.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-safe-2.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-safe-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-safe
hs-libraries:         HSpipes-safe-2.3.5-Ainp3R9oYLr5M6BNlGkAnB
depends:
    base-4.18.2.1 containers-0.6.7 exceptions-0.10.7
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    pipes-4.3.16-BeVHqcQKZUkHsDYr9zTHaP
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:   /usr/share/doc/haskell-pipes-safe/html/pipes-safe.haddock
haddock-html:         /usr/share/doc/haskell-pipes-safe/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
